@@ -2,8 +2,26 @@ from PySense import PySenseGroup, PySenseUser, PySenseUtils
 
 
 class Rule:
+    """A data security rule
+
+    A rule belongs to a single table.column
+    A column may have multiple rules. A rule belongs to a single table.column
+    Each rule has a list of groups and users that the rule applies to
+
+    Attributes:
+        json (JSON): The JSON for this object
+        py_client (PySense): The connection to the Sisense server which owns this asset
+    """
+
     def __init__(self, py_client, rule_json):
-        self._py_client = py_client
+        """
+
+        Args:
+            py_client (PySense): The PySense object for the server this asset belongs to
+            rule_json (JSON): The json for this object
+        """
+
+        self.py_client = py_client
         self._reset(rule_json)
 
     def _reset(self, rule_json):
@@ -13,36 +31,58 @@ class Rule:
                 share['party'] = share.pop('partyId')
         self._rule_json = rule_json
 
-    def get_shares(self):
-        """Returns the rules shares"""
+    def get_shares_json(self):
+        """Returns the rules shares as JSON"""
+
         return self._rule_json['shares']
 
+    def get_shares_user_groups(self):
+        """Returns the rules shares as users and groups
+
+        Returns:
+            list[User,Group]: Users and groups this rule is applied to
+        """
+        ret_arr = []
+        for share in self._rule_json['shares']:
+            if share['type'] == 'user':
+                ret_arr.append(self.py_client.get_user_by_id(share['party']))
+            elif share['type'] == 'group':
+                ret_arr.append(self.py_client.get_group_by_id(share['party']))
+        return ret_arr
+
     def get_id(self):
         """Gets the rule id."""
+
         return self._rule_json['_id']
 
     def get_column(self):
         """Gets the column for which the rule applies"""
+
         return self._rule_json['column']
 
     def get_table(self):
-        """ Gets the table for which the rule applies."""
+        """Gets the table for which the rule applies."""
+
         return self._rule_json['table']
 
     def get_members(self):
         """Gets the member values."""
+
         return self._rule_json['members']
 
     def get_data_type(self):
         """Gets the data type for which the rule applies."""
+
         return self._rule_json['datatype']
 
     def get_exclusionary(self):
         """Returns whether or not the rule is exclusionary"""
+
         return self._rule_json['exclusionary']
 
     def get_all_members(self):
         """Returns whether or not the rule is for all members."""
+
         return self._rule_json['exclusionary']
 
     def update_rule(self, *, table=None, column=None, data_type=None, shares='', members='',
@@ -52,14 +92,15 @@ class Rule:
         Any arguments given will replace the current value and update the rule in place
 
         Args:
-            shares: (optional) Array of users and groups to share the rule with
-            table: (optional) Table of the data security rule
-            column: (optional) Column of the data security rule
-            data_type: (optional) Data security rule data type
-            members: (optional) The values to specify in the rule. If blank, will use nothing
-            exclusionary: (optional) Set to true to make an exclusionary rule
-            all_members: (optional) Set to true for a rule to allow user to see all values
+            shares (list[User,Group]): (Optional) Array of users and groups to share the rule with
+            table (str): (Optional) Table of the data security rule
+            column (str): (Optional) Column of the data security rule
+            data_type (str): (Optional) Data security rule data type
+            members (list[str]): (Optional) The values to specify in the rule. If blank, will use nothing
+            exclusionary (bool): (Optional) Set to true to make an exclusionary rule
+            all_members (bool): (Optional) Set to true for a rule to allow user to see all values
         """
+
         rule_json = {
             "column": column if column is not None else self.get_column(),
             "datatype": data_type if data_type is not None else self.get_data_type(),
@@ -76,7 +117,7 @@ class Rule:
                     shares_json.append({'party': party.get_id(), 'type': 'group'})
             rule_json['shares'] = shares_json
         else:
-            rule_json['shares'] = self.get_shares()
+            rule_json['shares'] = self.get_shares_json()
 
         if members != '':
             if members is None:
@@ -91,6 +132,6 @@ class Rule:
         else:
             rule_json['members'] = self.get_members()
 
-        resp_json = self._py_client.connector.rest_call('put', 'api/elasticubes/datasecurity/{}'.format(self.get_id()),
-                                                        json_payload=rule_json)
+        resp_json = self.py_client.connector.rest_call('put', 'api/elasticubes/datasecurity/{}'.format(self.get_id()),
+                                                       json_payload=rule_json)
         self._reset(resp_json)
